@@ -25,6 +25,8 @@
 #include <bonobo/bonobo-socket.h>
 #include <bonobo/bonobo-exception.h>
 
+#undef BONOBO_CONTROL_FRAME_DEBUG
+
 enum {
 	ACTIVATED,
 	ACTIVATE_URI,
@@ -929,9 +931,12 @@ bonobo_control_frame_sync_realize (BonoboControlFrame *frame)
 	CORBA_exception_init (&ev);
 
 	Bonobo_Control_realize (control, &ev);
+
+#ifdef BONOBO_CONTROL_FRAME_DEBUG
 	if (BONOBO_EX (&ev))
 		g_warning ("Exception on realize '%s'",
 			   bonobo_exception_get_text (&ev));
+#endif
 
 	CORBA_exception_free (&ev);
 
@@ -957,9 +962,11 @@ bonobo_control_frame_sync_unrealize (BonoboControlFrame *frame)
 	CORBA_exception_init (&ev);
 
 	Bonobo_Control_unrealize (control, &ev);
+#ifdef BONOBO_CONTROL_FRAME_DEBUG
 	if (BONOBO_EX (&ev))
 		g_warning ("Exception on unrealize '%s'",
 			   bonobo_exception_get_text (&ev));
+#endif
 
 	CORBA_exception_free (&ev);
 
