@@ -415,12 +415,19 @@ impl_Bonobo_Control_setState (PortableServer_Servant      servant,
 			       CORBA_Environment          *ev)
 {
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
+	GtkStateType gtk_state = bonobo_control_gtk_state_from_corba (state);
 
 	g_return_if_fail (control->priv->widget != NULL);
 
-	gtk_widget_set_state (
-		control->priv->widget,
-		bonobo_control_gtk_state_from_corba (state));
+	if (gtk_state == GTK_STATE_INSENSITIVE)
+		gtk_widget_set_sensitive (control->priv->widget, FALSE);
+	else {
+		if (! GTK_WIDGET_SENSITIVE (control->priv->widget))
+			gtk_widget_set_sensitive (control->priv->widget, TRUE);
+
+		gtk_widget_set_state (control->priv->widget,
+				      gtk_state);
+	}
 }
 
 static Bonobo_PropertyBag
@@ -469,9 +476,9 @@ impl_Bonobo_Control_unrealize (PortableServer_Servant servant,
 }
 
 static CORBA_boolean
-impl_Bonobo_Control_focus (PortableServer_Servant servant,
-			   Bonobo_Control_FocusDirection corba_direction,
-			   CORBA_Environment *ev)
+impl_Bonobo_Control_focusChild (PortableServer_Servant servant,
+				Bonobo_Control_FocusDirection corba_direction,
+				CORBA_Environment *ev)
 {
 	BonoboControl *control;
 	BonoboControlPrivate *priv;
@@ -480,8 +487,6 @@ impl_Bonobo_Control_focus (PortableServer_Servant servant,
 	control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 	priv = control->priv;
 
-	/* FIXME: this will not work for local controls. */
-
 	if (!priv->plug)
 		return FALSE;
 
@@ -515,6 +520,7 @@ impl_Bonobo_Control_focus (PortableServer_Servant servant,
 		return FALSE;
 	}
 
+	bonobo_plug_clear_focus_chain (BONOBO_PLUG (priv->plug));
 	return gtk_container_focus (GTK_CONTAINER (priv->plug), direction);
 }
 
@@ -950,7 +956,7 @@ bonobo_control_class_init (BonoboControlClass *klass)
 	epv->getProperties  = impl_Bonobo_Control_getProperties;
 	epv->realize        = impl_Bonobo_Control_realize;
 	epv->unrealize      = impl_Bonobo_Control_unrealize;
-	epv->focus          = impl_Bonobo_Control_focus;
+	epv->focusChild     = impl_Bonobo_Control_focusChild;
 }
 
 static void
