@@ -435,6 +435,12 @@ bonobo_object_release_unref (Bonobo_Unknown     object,
 		CORBA_exception_init (rev);
 	}
 
+	if (BONOBO_OBJECT_IS_LOCAL (object) &&
+	    (ORBIT_ROOT_OBJECT (object)->refs <= 1))
+		g_error ("Incorrect CORBA OBJECT referencing somewhere, perhaps "
+			 "someone forget to CORBA_Object_duplicate before returning "
+			 "an object, or used bonobo_object_release_unref on a local object");
+
 	Bonobo_Unknown_unref (object, rev);
 	CORBA_Object_release (object, rev);
 
