@@ -246,6 +246,7 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
 	BonoboPlug *plug;
 	BonoboPlugPrivate *priv;
+	GtkContainer *container;
 	GtkWindow *window;
 	GtkDirectionType direction = 0;
 	gint return_val;
@@ -257,6 +258,7 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 	plug = BONOBO_PLUG (widget);
 	priv = plug->priv;
 
+	container = GTK_CONTAINER (widget);
 	window = GTK_WINDOW (widget);
 
 	if (!GTK_WIDGET_HAS_FOCUS (widget)) {
@@ -329,9 +331,9 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 				direction = GTK_DIR_UP; /* never reached, but makes compiler happy */
 			}
 
-			if (gtk_container_focus (GTK_CONTAINER (widget), direction))
-				g_assert (GTK_CONTAINER (widget)->focus_child != NULL);
-			else {
+			gtk_container_focus (container, direction);
+
+			if (!container->focus_child) {
 				gtk_window_set_focus (window, NULL);
 
 				gdk_error_trap_push ();
