@@ -496,7 +496,7 @@ bonobo_socket_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
 		gdk_error_trap_push ();
 		XSetInputFocus (GDK_DISPLAY (),
 				GDK_WINDOW_XWINDOW (priv->plug_window),
-				RevertToParent, last_x_time_stamp);
+				RevertToParent, CurrentTime);
 		gdk_flush();
 		gdk_error_trap_pop ();
 	}
@@ -520,7 +520,7 @@ bonobo_socket_focus_out_event (GtkWidget *widget, GdkEventFocus *event)
 	if (toplevel)
 		XSetInputFocus (GDK_DISPLAY (),
 				GDK_WINDOW_XWINDOW (toplevel->window),
-				RevertToParent, last_x_time_stamp);
+				RevertToParent, CurrentTime);
 
 	priv->gave_focus = FALSE;
 
@@ -550,7 +550,7 @@ claim_focus (BonoboSocket *socket)
 		gdk_error_trap_push ();
 		XSetInputFocus (GDK_DISPLAY (),
 				GDK_WINDOW_XWINDOW (priv->plug_window),
-				RevertToParent, last_x_time_stamp);
+				RevertToParent, CurrentTime);
 		gdk_flush ();
 		gdk_error_trap_pop ();
 	}
@@ -761,7 +761,7 @@ bonobo_socket_filter_func (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data
 			if (toplevel)
 				XSetInputFocus (GDK_DISPLAY (),
 						GDK_WINDOW_XWINDOW (toplevel->window),
-						RevertToParent, last_x_time_stamp);
+						RevertToParent, CurrentTime);
 #endif
 		}
 
