@@ -9,9 +9,10 @@
  */
 #include <config.h>
 #include <gnome.h>
-#include <bonobo.h>
+#include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-component.h>
+#include <bonobo/bonobo-ui-util.h>
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
 
@@ -650,6 +651,8 @@ impl_xml_set (BonoboUIComponent  *component,
  * Set the @xml fragment into the remote #BonoboUIContainer's tree
  * attached to @component at the specified @path
  * 
+ * It is likely that you don't want this routine, but want
+ * bonobo_ui_component_set_translate.
  **/
 void
 bonobo_ui_component_set_tree (BonoboUIComponent *component,
@@ -954,11 +957,15 @@ bonobo_ui_component_add_verb_list_with_data (BonoboUIComponent  *component,
 	g_return_if_fail (list != NULL);
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
 
+	bonobo_object_ref (BONOBO_OBJECT (component));
+
 	for (l = list; l && l->cname; l++) {
 		bonobo_ui_component_add_verb (
 			component, l->cname, l->cb,
 			user_data?user_data:l->user_data);
 	}
+
+	bonobo_object_unref (BONOBO_OBJECT (component));
 }
 
 /**
@@ -1113,6 +1120,8 @@ impl_set_prop (BonoboUIComponent  *component,
 	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
+	bonobo_object_ref (BONOBO_OBJECT (component));
+
 	node = bonobo_ui_component_get_tree (
 		component, path, FALSE, opt_ev);
 
@@ -1128,6 +1137,8 @@ impl_set_prop (BonoboUIComponent  *component,
 	g_free (parent_path);
 
 	bonobo_ui_node_free (node);
+
+	bonobo_object_unref (BONOBO_OBJECT (component));
 }
 
 /**
@@ -1293,6 +1304,8 @@ bonobo_ui_component_unset_container (BonoboUIComponent *component)
 {
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
 
+	bonobo_object_ref (BONOBO_OBJECT (component));
+
 	if (component->priv->container != CORBA_OBJECT_NIL) {
 		CORBA_Environment  ev;
 		char              *name;
@@ -1313,9 +1326,12 @@ bonobo_ui_component_unset_container (BonoboUIComponent *component)
 		CORBA_exception_free (&ev);
 
 		bonobo_object_release_unref (component->priv->container, NULL);
+
 	}
 
 	component->priv->container = CORBA_OBJECT_NIL;
+
+	bonobo_object_unref (BONOBO_OBJECT (component));
 }
 
 /**
@@ -1334,6 +1350,8 @@ bonobo_ui_component_set_container (BonoboUIComponent *component,
 
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
 
+	bonobo_object_ref (BONOBO_OBJECT (component));
+
 	if (container != CORBA_OBJECT_NIL) {
 		Bonobo_UIComponent corba_component;
 		char              *name;
@@ -1362,6 +1380,8 @@ bonobo_ui_component_set_container (BonoboUIComponent *component,
 	bonobo_ui_component_unset_container (component);
 
 	component->priv->container = ref_cont;
+
+	bonobo_object_unref (BONOBO_OBJECT (component));
 }
 
 /**
