@@ -358,6 +358,12 @@ bonobo_ui_container_set_win (BonoboUIContainer *container,
  * This is _extremely_ deprecated, there is no garentee
  * that a BonoboUIContainer has an associated window, this
  * function will spew warnings.
+ *
+ * If you find yourself wanting to use this function,
+ * you probably want to be passing a BonoboWindow ( or
+ * derivative ) around and then using:
+ *
+ * bonobo_window_get_ui_engine (window)
  * 
  * Return value: a BonoboWindow if it is associated.
  **/
@@ -366,7 +372,7 @@ bonobo_ui_container_get_win (BonoboUIContainer *container)
 {
 	g_return_val_if_fail (BONOBO_IS_UI_CONTAINER (container), NULL);
 
-	g_warning ("bonobo_ui_container_get_win is deprecated");
+/*	g_warning ("bonobo_ui_container_get_win is deprecated");*/
 
 	return container->win;
 }
