@@ -9,6 +9,7 @@
  */
 
 #include "config.h"
+#include <stdlib.h>
 #include <bonobo/bonobo-ui-node.h>
 
 #include <gnome-xml/parser.h>
@@ -60,7 +61,7 @@ bonobo_ui_node_new_child (BonoboUINode *parent,
  * 
  * Copy an XML node, if @recursive do a deep copy, otherwise just dup the node itself.
  * 
- * Return value: a copy of the noce
+ * Return value: a copy of the node
  **/
 BonoboUINode*
 bonobo_ui_node_copy (BonoboUINode *node,
@@ -302,7 +303,7 @@ bonobo_ui_node_next (BonoboUINode *node)
  * bonobo_ui_node_prev:
  * @node: the node
  * 
- * Return value: the node after @node in the list
+ * Return value: the node before @node in the list
  **/
 BonoboUINode*
 bonobo_ui_node_prev (BonoboUINode *node)
