@@ -23,18 +23,15 @@ BEGIN_GNOME_DECLS
 #define BONOBO_IS_UI_TOOLBAR_BUTTON_ITEM(obj)		(GTK_CHECK_TYPE ((obj), BONOBO_TYPE_UI_TOOLBAR_BUTTON_ITEM))
 #define BONOBO_IS_UI_TOOLBAR_BUTTON_ITEM_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((obj), BONOBO_TYPE_UI_TOOLBAR_BUTTON_ITEM))
 
-
-typedef struct _BonoboUIToolbarButtonItem        BonoboUIToolbarButtonItem;
 typedef struct _BonoboUIToolbarButtonItemPrivate BonoboUIToolbarButtonItemPrivate;
-typedef struct _BonoboUIToolbarButtonItemClass   BonoboUIToolbarButtonItemClass;
 
-struct _BonoboUIToolbarButtonItem {
+typedef struct {
 	BonoboUIToolbarItem parent;
 
 	BonoboUIToolbarButtonItemPrivate *priv;
-};
+} BonoboUIToolbarButtonItem;
 
-struct _BonoboUIToolbarButtonItemClass {
+typedef struct {
 	BonoboUIToolbarItemClass parent_class;
 
 	/* Virtual methods */
@@ -46,9 +43,8 @@ struct _BonoboUIToolbarButtonItemClass {
 	/* Signals.  */
 	void (* clicked)	(BonoboUIToolbarButtonItem *toolbar_button_item);
 	void (* set_want_label) (BonoboUIToolbarButtonItem *toolbar_button_item);
-};
+} BonoboUIToolbarButtonItemClass;
 
-
 GtkType    bonobo_ui_toolbar_button_item_get_type           (void);
 void       bonobo_ui_toolbar_button_item_construct          (BonoboUIToolbarButtonItem *item,
 							     GtkButton                 *button_widget,
