@@ -614,7 +614,7 @@ bonobo_help_display_cb (BonoboUIComponent *component,
  * Cut and paste job so we can overcome gnome-libs brokenness.
  */
 static char *
-bonobo_help_file_find_file (const char *prefix, const char *app,
+bonobo_help_file_find_file (const char *datadir, const char *app,
 			    const char *path)
 {
 	GList *language_list;
@@ -632,7 +632,7 @@ bonobo_help_file_find_file (const char *prefix, const char *app,
 		
 		buf = g_string_new (NULL);
 		g_string_sprintf (buf, "%s/gnome/help/%s/%s/%s",
-				  prefix, app, lang, path);
+				  datadir, app, lang, path);
 		res = g_strdup (buf->str);
 		p = strrchr (res, '#');
 		if (p) {
@@ -660,7 +660,7 @@ bonobo_help_file_find_file (const char *prefix, const char *app,
 /**
  * bonobo_ui_util_build_help_menu:
  * @listener: associated component
- * @app_prefix: application prefix
+ * @app_datadir: application datadir
  * @app_name: application name
  * @parent: toplevel node
  * 
@@ -669,7 +669,7 @@ bonobo_help_file_find_file (const char *prefix, const char *app,
  **/
 void
 bonobo_ui_util_build_help_menu (BonoboUIComponent *listener,
-				const char        *app_prefix,
+				const char        *app_datadir,
 				const char        *app_name,
 				BonoboUINode      *parent)
 {
@@ -685,9 +685,9 @@ bonobo_ui_util_build_help_menu (BonoboUIComponent *listener,
 	topic_file = gnome_help_file_find_file ((char *)app_name, "topic.dat");
 	
 	/* Do something sensible */
-	if (!topic_file && app_prefix)
+	if (!topic_file && app_datadir)
 		topic_file = bonobo_help_file_find_file (
-			app_prefix, app_name, "topic.dat");
+			app_datadir, app_name, "topic.dat");
 
 	if (!topic_file || !(file = fopen (topic_file, "rt"))) {
 		g_warning ("Could not open help topics file %s for app %s", 
@@ -982,7 +982,7 @@ bonobo_ui_util_new_toggle_toolbar (const char *name,
 
 /**
  * bonobo_ui_util_get_ui_fname:
- * @component_prefix: the prefix for the component.
+ * @component_datadir: the datadir for the component.
  * @file_name: the file name of the xml file.
  * 
  * Builds a path to the xml file that stores the GUI.
@@ -991,7 +991,7 @@ bonobo_ui_util_new_toggle_toolbar (const char *name,
  * UI or NULL if it is not found.
  **/
 char *
-bonobo_ui_util_get_ui_fname (const char *component_prefix,
+bonobo_ui_util_get_ui_fname (const char *component_datadir,
 			     const char *file_name)
 {
 	char *fname, *name;
@@ -1018,9 +1018,9 @@ bonobo_ui_util_get_ui_fname (const char *component_prefix,
 	/*
 	 * The master copy
 	 */
-	if (component_prefix) {
+	if (component_datadir) {
 		fname = g_strdup_printf ("%s/gnome/ui/%s",
-					 component_prefix, file_name);
+					 component_datadir, file_name);
 		if (g_file_exists (fname))
 			return fname;
 		g_free (fname);
@@ -1097,7 +1097,7 @@ bonobo_ui_util_translate_ui (BonoboUINode *bnode)
  * bonobo_ui_util_fixup_help:
  * @component: the UI component
  * @node: the node to search under
- * @app_prefix: the application prefix
+ * @app_datadir: the application datadir
  * @app_name: the application name
  * 
  * This searches for 'BuiltMenuItems' placeholders, and then
@@ -1106,7 +1106,7 @@ bonobo_ui_util_translate_ui (BonoboUINode *bnode)
 void
 bonobo_ui_util_fixup_help (BonoboUIComponent *component,
 			   BonoboUINode      *node,
-			   const char        *app_prefix,
+			   const char        *app_datadir,
 			   const char        *app_name)
 {
 	BonoboUINode *l;
@@ -1126,11 +1126,11 @@ bonobo_ui_util_fixup_help (BonoboUIComponent *component,
 
 	if (build_here) {
 		bonobo_ui_util_build_help_menu (
-			component, app_prefix, app_name, node);
+			component, app_datadir, app_name, node);
 	}
 
 	for (l = bonobo_ui_node_children (node); l; l = bonobo_ui_node_next (l))
-		bonobo_ui_util_fixup_help (component, l, app_prefix, app_name);
+		bonobo_ui_util_fixup_help (component, l, app_datadir, app_name);
 }
 
 /**
@@ -1201,7 +1201,7 @@ bonobo_ui_util_fixup_icons (BonoboUINode *node)
 BonoboUINode *
 bonobo_ui_util_new_ui (BonoboUIComponent *component,
 		       const char        *file_name,
-		       const char        *app_prefix,
+		       const char        *app_datadir,
 		       const char        *app_name)
 {
 	BonoboUINode *node;
@@ -1215,7 +1215,7 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
 
 	bonobo_ui_util_translate_ui (node);
 
-	bonobo_ui_util_fixup_help (component, node, app_prefix, app_name);
+	bonobo_ui_util_fixup_help (component, node, app_datadir, app_name);
 
 	bonobo_ui_util_fixup_icons (node);
 
@@ -1225,8 +1225,8 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
 /**
  * bonobo_ui_util_set_ui:
  * @component: the component
- * @app_prefix: the application prefix eg. /opt/gnome
- * @file_name: the filename of the file to merge relative to the prefix.
+ * @app_datadir: the application datadir eg. /opt/gnome/share
+ * @file_name: the filename of the file to merge relative to the datadir.
  * @app_name: the application name - for help merging
  * 
  * This function loads the UI from the associated file, translates it,
@@ -1236,7 +1236,7 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
  **/
 void
 bonobo_ui_util_set_ui (BonoboUIComponent *component,
-		       const char        *app_prefix,
+		       const char        *app_datadir,
 		       const char        *file_name,
 		       const char        *app_name)
 {
@@ -1249,13 +1249,13 @@ bonobo_ui_util_set_ui (BonoboUIComponent *component,
 		return;
 	}
 	
-	fname = bonobo_ui_util_get_ui_fname (app_prefix, file_name);
+	fname = bonobo_ui_util_get_ui_fname (app_datadir, file_name);
 	if (!fname) {
 		g_warning ("Can't find '%s' to load ui from", file_name);
 		return;
 	}
 	
-	ui = bonobo_ui_util_new_ui (component, fname, app_prefix, app_name);
+	ui = bonobo_ui_util_new_ui (component, fname, app_datadir, app_name);
 	
 	if (ui)
 		bonobo_ui_component_set_tree (
