@@ -22,11 +22,6 @@
 /* Parent object class in GTK hierarchy */
 static BonoboControlClass *bonobo_view_parent_class;
 
-/* The entry point vectors for the server we provide */
-POA_Bonobo_View__epv    bonobo_view_epv;
-POA_Bonobo_Control__epv bonobo_view_overridden_control_epv;
-POA_Bonobo_View__vepv   bonobo_view_vepv;
-
 enum {
 	VIEW_UNDO_LAST_OPERATION,
 	SET_ZOOM_FACTOR,
