@@ -11,7 +11,6 @@
 #include <libgnomeui/gnome-dock-item.h>
 #include <libgnomeui/gnome-dock.h>
 #include <libgnomeui/gnome-preferences.h>
-#include <bonobo.h>
 #include <liboaf/liboaf.h>
 
 #include <bonobo/bonobo-ui-engine.h>
@@ -19,6 +18,7 @@
 #include <bonobo/bonobo-ui-sync-keys.h>
 #include <bonobo/bonobo-ui-sync-status.h>
 #include <bonobo/bonobo-ui-sync-toolbar.h>
+#include <bonobo/bonobo-win.h>
 
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
