@@ -434,10 +434,26 @@ bonobo_x_object (gpointer p)
 
 	if (!p)
 		return NULL;
-	
-	if ((xobj = BONOBO_X_SERVANT_GET_OBJECT (p))->flags ==
-	    BONOBO_X_SERVANT_FLAG_PATTERN)
+
+	xobj = p;
+
+	if (xobj->base.corba_objref ==
+	    BONOBO_X_OBJECT_GET_CORBA (xobj) &&
+	    xobj->base.servant ==
+	    BONOBO_X_OBJECT_GET_SERVANT (xobj))
 		return xobj;
 
-	return BONOBO_X_OBJECT (p);
+	else {
+		BonoboObjectServant *s = p;
+
+		if ((xobj = s->bonobo_object) ==
+		    BONOBO_X_SERVANT_GET_OBJECT (s) &&
+		    &xobj->servant == p)
+			return xobj;
+		else
+			g_warning ("Serious error, unidentifiable "
+				   "pointer type");
+	}
+
+	return NULL;
 }
