@@ -40,7 +40,7 @@ gzstream_get_byte (EFSFile *file)
 		res = file->efs->driver->fops->
 			file_read (file, s->inbuf, Z_BUFSIZE,
 				   &s->stream.avail_in);
-		if ((res == EFS_ERR_EOF || !s->stream.avail_in)) s->eof = 1;
+		if (!res && !s->stream.avail_in) s->eof = 1;
 		else if (res) { s->err = Z_ERRNO; return EOF; }
 
 		s->stream.next_in = s->inbuf;
@@ -387,12 +387,13 @@ efs_file_read (EFSFile *file, gpointer buf, gint32 count, guint32 *bytes_read)
 		while (s->stream.avail_out != 0) {
 			if (s->stream.avail_in == 0 && !s->eof) {
 				if (!(res = file->efs->driver->fops->
-				      file_read(file,s->inbuf,Z_BUFSIZE,&br)))
+				      file_read(file,s->inbuf,Z_BUFSIZE,&br))){
 					s->stream.avail_in = br;
-				else {
-					if (res == EFS_ERR_EOF) s->eof = 1;
-					else { s->err = Z_ERRNO; break; }
+					if (!br) s->eof = 1;
+				} else {
+					s->err = Z_ERRNO; break;
 				}
+
 				s->stream.next_in = s->inbuf;
 			}
 			
@@ -752,3 +753,25 @@ efs_rename (EFSDir *dir, const char *old_path, const char *new_path)
 }
 
 
+/**
+ * efs_node_equal:
+ * @node1: reference to a node
+ * @node2: reference to a node
+ *
+ * Description: Check if the nodes are equal.
+ *
+ * Returns: TRUE if the nodes are equal, FALSE otherwise.
+ */
+
+gboolean
+efs_node_equal (EFSNode *node1, EFSNode *node2)
+{
+	g_return_val_if_fail (node1 != NULL, FALSE);
+	g_return_val_if_fail (node2 != NULL, FALSE);
+
+	if (node1->efs != node2->efs) return FALSE;
+	
+	return node1->efs->driver->fops->node_equal (node1, node2);
+}
+
+
