@@ -17,6 +17,8 @@
 
 #include "bonobo-moniker-std.h"
 
+extern gchar * bonobo_internal_get_major_mime_type (const char *mime_type);
+
 Bonobo_Unknown
 bonobo_file_extender_resolve (BonoboMonikerExtender *extender,
 			      const Bonobo_Moniker   m,
@@ -26,6 +28,7 @@ bonobo_file_extender_resolve (BonoboMonikerExtender *extender,
 			      CORBA_Environment     *ev)
 {
 	const char         *mime_type;
+	char               *mime_type_major;
 	char               *oaf_requirements;
 	Bonobo_Unknown      object;
 	Bonobo_Persist      persist;
@@ -42,19 +45,23 @@ bonobo_file_extender_resolve (BonoboMonikerExtender *extender,
 	g_warning ("Filename : '%s'", fname);
 
 	mime_type = gnome_mime_type (fname);
-
+	mime_type_major = bonobo_internal_get_major_mime_type (mime_type);
+	
 	oaf_requirements = g_strdup_printf (
-		"bonobo:supported_mime_types.has ('%s') AND repo_ids.has ('%s') AND "
+		"bonobo:supported_mime_types.has_one (['%s', '%s/*']) AND "
+		"repo_ids.has ('%s') AND "
 		"repo_ids.has ('IDL:Bonobo/PersistFile:1.0')",
-		mime_type, requested_interface);
-		
+		mime_type, mime_type_major,
+		requested_interface);
+	
 	result = oaf_query (oaf_requirements, NULL, ev);
 	if (BONOBO_EX (ev) || result == NULL || result->_buffer == NULL ||
 	    !result->_buffer[0].iid)
 		return CORBA_OBJECT_NIL;
 
 	g_free (oaf_requirements);
-
+	g_free (mime_type_major);
+	
 	oafiid = g_strdup (result->_buffer[0].iid);
 
 	CORBA_free (result);
