@@ -1,4 +1,4 @@
-/* $Id: component.c,v 1.21 2001/02/06 21:43:09 michael Exp $ */
+/* $Id: component.c,v 1.23 2001/02/08 23:37:43 michael Exp $ */
 
 #include "component.h"
 #include "embeddable-io.h"
@@ -320,32 +320,16 @@ sample_client_site_class_init (SampleClientSiteClass *klass)
 	object_class->destroy = sample_client_site_destroy;
 }
 
-GtkType
-sample_client_site_get_type (void)
+static void 
+sample_client_site_init (GtkObject *object)
 {
-	static GtkType type = 0;
-
-	if (!type) {
-		GtkTypeInfo info = {
-			"SampleClientSite",
-			sizeof (SampleClientSite),
-			sizeof (SampleClientSiteClass),
-			(GtkClassInitFunc) sample_client_site_class_init,
-			(GtkObjectInitFunc) NULL,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		type = bonobo_x_type_unique (
-			bonobo_client_site_get_type (),
-			NULL, NULL, 0,
-			&info);
-	}
-
-	return type;
+	/* nothing to do */
 }
 
+BONOBO_X_TYPE_FUNC (SampleClientSite, 
+		      bonobo_client_site_get_type (),
+		      sample_client_site);
+
 static void
 site_create_widgets (SampleClientSite *site)
 {
