@@ -44,6 +44,6 @@ control_factory (BonoboGenericFactory *this,
 }
 
 BONOBO_OAF_FACTORY_MULTI ("OAFIID:Bonobo_Sample_ControlFactory",
-			  "bonobo-sample-controls",
+			  "bonobo-sample-controls", VERSION,
 			  control_factory,
 			  NULL)
