@@ -1,5 +1,5 @@
 /*
- * app.c: A test application to hammer the Bonobo UI api.
+ * test-ui.c: A test application to hammer the Bonobo UI api.
  *
  * NB. To run this program and test the xml IO code you
  * need to do something like ln -s /{prefix}/bonobo/doc/std-ui.xml ~/.gnome/ui
@@ -7,7 +7,7 @@
  * Author:
  *	Michael Meeks (michael@helixcode.com)
  *
- * Copyright 2000 Helix Code, Inc.
+ * Copyright 2000 Ximian, Inc.
  */
 
 #include "config.h"
@@ -222,6 +222,8 @@ main (int argc, char **argv)
 	gnome_init_with_popt_table ("container", VERSION,
 				    argc, argv, oaf_popt_options, 0, &ctx);
 
+	textdomain (PACKAGE);
+
 	orb = oaf_init (argc, argv);
 
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
@@ -485,6 +487,10 @@ main (int argc, char **argv)
 				    disconnect_progress, GUINT_TO_POINTER (id));
 	}
 
+	bonobo_ui_component_set_status (componenta, "This is a very long status message "
+					"that should cause the window to be resized if "
+					"there is in fact a bug in it", NULL);
+
 	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
 	bonobo_ui_component_freeze (componenta, NULL);
